<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Rasporedi</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Premjesti skroz naprijed</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Premjesti prema naprijed</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Premjesti prema natrag</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Premjesti skroz natrag</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Odaberi ovo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Umetni</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Kontrole</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Opće postavke</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Postavke slike</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Boja</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Boja teksta</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Brojač</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Faktor zamućenja</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Sjena elementa</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Postavke elementa</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Omjer</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Neprozirnost</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zatvori ostale</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zatvori sve</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Zatvori sve na lijevo</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Zatvori sve na desno</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Odabir alata</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktivirano</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktivirano</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Poništi</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Omjer</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Okreni</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Promijeni platno</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Primijeni</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Okomito</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vodoravno</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Primijeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Vidljivost ruba i ispune</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Rub i ispuna</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Rub i bez ispune</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Bez ruba i bez ispune</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Veličina fonta</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Podebljano</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurziv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podcrtano</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Slikovni efekti</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Bez efekta</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Odmaknuta sjena</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Crno-bijela</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rub</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertiraj boju</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Ograničeno</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Kad je aktivirano, područje crtanja
uključuje sliku pozadine.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Primijeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Boja:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Boja pozadine patna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Okreni sliku</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° nadesno</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° nalijevo</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Proizvoljno</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Pozitivne vrijednosti okreću sliku u smjeru kazaljke na satu, negativne u suprotnom smjeru kazaljke na satu.
Okretanje množiteljima koji nisu 90° može smanjiti kvalitetu slike.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vodoravno</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Okomito</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Okreni</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Preokreni</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skaliraj sliku</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Zadrži omjer</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Visina:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Postotak</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Naljepnica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Odaberi</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Olovka</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Broj</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Pravokutni odabir</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Ovalni odabir</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Prostoručni odabir</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strelica</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dvostruka strelica</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Crta</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Mutnoća</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Pravokutnik</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Oval</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Pokazivač s brojem</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Naljepnica</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliciraj</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Pokazivač s tekstom</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Strelica s tekstom</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Strelica s brojem</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikseliziraj</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Povećaj (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Smanji (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Poništi zumiranje (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Resetiraj zumiranje</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Prilagodi sliku</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Prilagodi sliku za prikaz (%1)</translation>
    </message>
</context>
</TS>
